@@ -1,4 +1,4 @@
-/* $Id: read_data.c,v 1.20 2004/12/29 00:14:29 bdejean Exp $ */
+/* $Id: read_data.c,v 1.22 2005/03/29 13:18:15 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -23,6 +23,7 @@
 
 #include <config.h>
 
+#include <glibtop/error.h>
 #include <glibtop/read_data.h>
 #include "libgtop-i18n.h"
 
@@ -70,7 +71,8 @@ glibtop_read_data_l (glibtop *server)
 		glibtop_error_io_r (server,
 				    ngettext ("read %lu byte of data",
 					      "read %lu bytes of data",
-					      (unsigned long) size));
+					      (unsigned long) size),
+				    (unsigned long) size);
 
 	return ptr;
 }
