@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: mem.c,v 1.9 2004/06/09 18:52:22 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -33,22 +31,18 @@ static const unsigned long _glibtop_sysdeps_mem = 0;
 
 /* Init function. */
 
-int
+void
 glibtop_init_mem_p (glibtop *server)
 {
-    server->sysdeps.mem = _glibtop_sysdeps_mem;
-
-    return 0;
+	server->sysdeps.mem = _glibtop_sysdeps_mem;
 }
 
 /* Provides information about memory usage. */
 
-int
+void
 glibtop_get_mem_p (glibtop *server, glibtop_mem *buf)
 {
-    glibtop_init_p (server, GLIBTOP_SYSDEPS_MEM, 0);
-	
-    memset (buf, 0, sizeof (glibtop_mem));
+	glibtop_init_p (server, GLIBTOP_SYSDEPS_MEM, 0);
 
-    return 0;
+	memset (buf, 0, sizeof (glibtop_mem));
 }
